import logging

from zrb.config.config import logging_level
from zrb.helper.accessories.untyped_color import untyped_colored as colored

# create logger
logger = logging.getLogger("zrb")
logger.setLevel(logging_level)

# create console handler and set level to debug
ch = logging.StreamHandler()
ch.setLevel(logging_level)

# create formatter
formatter = logging.Formatter(
    colored("%(levelname)-6s %(asctime)s", attrs=["dark"]) + " %(message)s"
)

# add formatter to ch
ch.setFormatter(formatter)

# add ch to logger
logger.addHandler(ch)



from zrb.config.config import enable_type_checking
from zrb.helper.accessories.untyped_color import untyped_colored as colored
from zrb.helper.log import logger

logger.debug(colored("Loading zrb.helper.typing", attrs=["dark"]))

if enable_type_checking:
    from beartype.typing import (
        Any,
        Callable,
        Iterable,
        List,
        Mapping,
        Optional,
        Tuple,
        Type,
        TypeVar,
        Union,
    )
else:
    from typing import (
        Any,
        Callable,
        Iterable,
        List,
        Mapping,
        Optional,
        Tuple,
        Type,
        TypeVar,
        Union,
    )

JinjaTemplate = str

assert Any
assert Iterable
assert Callable
assert List
assert Mapping
assert Optional
assert TypeVar
assert Type
assert Tuple
assert Union



from zrb.helper.accessories.color import colored
from zrb.helper.log import logger
from zrb.helper.typecheck import typechecked
from zrb.task.base_task.base_task import BaseTask

logger.debug(colored("Loading zrb.task.task", attrs=["dark"]))


@typechecked
class Task(BaseTask):
    """
    Alias for BaseTask.
    """

    pass



from helper.value import utcnow
from sqlalchemy import Column, DateTime, String
from sqlalchemy.orm import declarative_mixin
from ulid import ULID


def generate_primary_key() -> str:
    return str(ULID())


@declarative_mixin
class DBEntityMixin:
    id = Column(String(36), primary_key=True, index=True, default=generate_primary_key)
    created_at = Column(DateTime, default=utcnow)
    created_by = Column(String(36), nullable=True)
    updated_at = Column(DateTime, nullable=True)
    updated_by = Column(String(36), nullable=True)



from zrb.helper.accessories.color import colored
from zrb.helper.log import logger
from zrb.helper.typecheck import typechecked
from zrb.helper.typing import Mapping

logger.debug(colored("Loading zrb.helper.string.parse_replacment", attrs=["dark"]))


@typechecked
def parse_replacement(text: str, replacement: Mapping[str, str]):
    new_text = text
    for old, new in replacement.items():
        new_text = new_text.replace(old, new)
    return new_text
